"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseEnv = void 0;
const zod_1 = require("zod");
// load upload configuration from environment
const envSchema = zod_1.z
    .object({
    CP_SERVER: zod_1.z.string().url().optional(),
    CP_API_KEY: zod_1.z.string().min(1).optional(),
    CP_ORGANIZATION: zod_1.z.string().min(1).optional(),
    CP_PROJECT: zod_1.z.string().min(1).optional(),
    CP_TIMEOUT: zod_1.z.string().regex(/^\d+$/).optional(),
})
    .partial();
function parseEnv(env = {}) {
    const upload = envSchema.parse(env);
    // eslint-disable-next-line @typescript-eslint/no-unsafe-return
    return Object.fromEntries(Object.entries(upload).map(([envKey, value]) => {
        switch (envKey) {
            case 'CP_SERVER':
                return ['server', value];
            case 'CP_API_KEY':
                return ['apiKey', value];
            case 'CP_ORGANIZATION':
                return ['organization', value];
            case 'CP_PROJECT':
                return ['project', value];
            case 'CP_TIMEOUT':
                return Number(value) >= 0 ? ['timeout', Number(value)] : [];
            default:
                return [];
        }
    }));
}
exports.parseEnv = parseEnv;
//# sourceMappingURL=env.js.map