"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.initSchematic = exports.initGenerator = void 0;
/* eslint-disable functional/immutable-data */
const devkit_1 = require("@nx/devkit");
const constants_1 = require("../../internal/constants");
const versions_1 = require("../../internal/versions");
function checkDependenciesInstalled(host) {
    const packageJson = (0, devkit_1.readJson)(host, 'package.json');
    const devDependencies = {};
    const dependencies = {};
    packageJson.dependencies = packageJson.dependencies ?? {};
    packageJson.devDependencies = packageJson.devDependencies ?? {};
    // base deps
    devDependencies[constants_1.PACKAGE_NAME] = versions_1.cpNxPluginVersion;
    devDependencies['@code-pushup/models'] = versions_1.cpModelVersion;
    devDependencies['@code-pushup/utils'] = versions_1.cpUtilsVersion;
    devDependencies['@code-pushup/cli'] = versions_1.cpCliVersion;
    return (0, devkit_1.addDependenciesToPackageJson)(host, dependencies, devDependencies);
}
function moveToDevDependencies(tree) {
    (0, devkit_1.updateJson)(tree, 'package.json', (packageJson) => {
        const newPackageJson = {
            dependencies: {},
            devDependencies: {},
            ...packageJson,
        };
        if (newPackageJson.dependencies?.[constants_1.PACKAGE_NAME] !== undefined) {
            const { [constants_1.PACKAGE_NAME]: version, ...dependencies } = newPackageJson.dependencies;
            return {
                ...newPackageJson,
                dependencies,
                devDependencies: {
                    ...newPackageJson.devDependencies,
                    [constants_1.PACKAGE_NAME]: version,
                },
            };
        }
        return newPackageJson;
    });
}
function updateNxJsonConfig(tree) {
    const nxJson = (0, devkit_1.readNxJson)(tree);
    const targetName = 'code-pushup';
    nxJson.targetDefaults ??= {};
    nxJson.targetDefaults[targetName] = {
        inputs: ['default', '^production'],
        cache: true,
    };
    (0, devkit_1.updateNxJson)(tree, nxJson);
}
function initGenerator(tree, schema) {
    if (schema.skipNxJson) {
        devkit_1.logger.info(`Skip updating nx.json`);
    }
    else {
        updateNxJsonConfig(tree);
    }
    const tasks = [];
    if (schema.skipPackageJson) {
        devkit_1.logger.info(`Skip updating package.json`);
    }
    else {
        moveToDevDependencies(tree);
        const installDependencies = checkDependenciesInstalled(tree);
        if (schema.skipInstall) {
            devkit_1.logger.info(`Skip installing packages`);
        }
        else {
            tasks.push(installDependencies);
        }
    }
    return (0, devkit_1.runTasksInSerial)(...tasks);
}
exports.initGenerator = initGenerator;
exports.default = initGenerator;
exports.initSchematic = (0, devkit_1.convertNxGenerator)(initGenerator);
//# sourceMappingURL=generator.js.map